import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.*;
/**
 * Implementing the GUI.
 * 
 */
public class Morse extends World
{
    private static final int ROWS = 15;
    private Translator parser = new Translator();
    private String input = new String();
    private String[] letters = { "", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "q", "w", "e", "r", "t", "y", "u", "i", "o", "p", "a", "s", "d", "f", "g", "h", "j", "k", "l", ":", "z", "x", "c", "v", "b", "n", "m", ",", ".", "?" };
    private boolean morse;
    private Output output;
    private int lineWidth = 320;
    
    public Morse() {    
        super(320, 480, 1);
        morseboard();
    }

    public void process(String symbol) {
        if(symbol.equals("morse")) {
            input = "";
            morseboard();
        }
        if(symbol.equals("text")) {
            input = "";
            keyboard();
        }
        if((symbol.equals(".") || symbol.equals("-") || symbol.equals(" ") || symbol.equals("/") || symbol.equals("#")) && morse) {
            input += symbol;
            if(stringWidth(input) >= lineWidth && lineWidth < ROWS*320) {
                input += "\n";
                lineWidth += 320;
            }
            output.update(input);
        }
        if(symbol.equals(" ") && !morse) {
            input += symbol;
            if(stringWidth(input) >= lineWidth && lineWidth < ROWS*320) {
                input += "\n";
                lineWidth += 320;
            }
            output.update(input);
        }
        if(symbol.equals("backspace")) {
            if(input.length() >= 1) {             
                if(stringWidth(input) <= lineWidth-320 && lineWidth >= 0) {
                    lineWidth -= 320;
                }
                input = input.substring(0,input.length()-1); 
                output.update(input);
            }
        }
        if(symbol.equals("enter")) {
            String m = "";
            if(morse) {
                m = parser.decrypt(input);
            }
            else {
                m = parser.encrypt(input);
            }
            char[] txt = m.toCharArray();
            String n = "";
            lineWidth = 320;
            for(int i=0; i < txt.length; i++) {
                n += txt[i];           
                if(stringWidth(n) >= lineWidth && lineWidth < ROWS*320) {
                    n += "\n";
                    lineWidth += 320;
                }
            }
            output.update(n);
            input = "";
            lineWidth = 320;
        }
        for(int i=0; i < letters.length; i++) {
            if(symbol.equals(letters[i]) && !morse) {
                input += symbol;
                if(stringWidth(input) >= lineWidth && lineWidth < ROWS*320) {
                    input += "\n";
                    lineWidth += 320;
                }            
                output.update(input);
            }
        }
    }
    
    private void keyboard() {
        removeObjects(getObjects(null));
        morse = false;
        lineWidth = 320;
        GreenfootImage background = new GreenfootImage("images/keys.jpg");
        setBackground(background);
        output = new Output();
        addObject(output, 160, 140);
        addObject(new Input(160, 30, "morse"), 80, 15);
        addObject(new Input(160, 30, "text"), 240, 15);
        addObject(new Input(192, 32, " "), 160, 464);
        addObject(new Input(64, 32, "backspace"), 32, 464);
        addObject(new Input(64, 32, "enter"), 288, 464);
        int y = 336;
        int x = 16;
        for(int i=1; i < letters.length; i++) {
            addObject(new Input(32, 32, letters[i]), x, y);
            x += 32;
            if(i % 10 == 0) {
                y += 32;
                x = 16;
            }
        }
    }
    
    private void morseboard() {
        removeObjects(getObjects(null));
        morse = true;
        lineWidth = 320;
        GreenfootImage background = new GreenfootImage("images/morse.jpg");
        setBackground(background);
        output = new Output();
        addObject(output, 160, 140);
        addObject(new Input(160, 30, "morse"), 80, 15);
        addObject(new Input(160, 30, "text"), 240, 15);
        addObject(new Input(320, 40, "/"), 160, 270);
        addObject(new Input(160, 150, "."), 80, 365);
        addObject(new Input(160, 150, "-"), 240, 365);
        addObject(new Input(160, 40, " "), 160, 460);
        addObject(new Input(80, 40, "backspace"), 40, 460);
        addObject(new Input(80, 40, "enter"), 280, 460);
    }
    
    private int stringWidth(String s) {
        GreenfootImage str = new GreenfootImage(input,14,Color.WHITE, Color.BLACK);
        FontMetrics metrics = str.getAwtImage().getGraphics().getFontMetrics(str.getFont());
        int width = metrics.charsWidth(s.toCharArray(), 0, s.length());
        return width;
    }
}
